@@ -2,6 +2,8 @@
 Compare the generated C code against the NumPy reference code.
 """
 
+import tempfile
+import shutil
 import numpy as np
 import pytest
 
@@ -27,11 +29,14 @@ def test_c_collocation_codgen(AM, grad):
 @pytest.mark.parametrize("AM", list(range(4)))
 def test_c_spherical_trans_codgen(AM):
     cg = gg.codegen.CodeGen(cgen=True)
-    gg.RSH.transformation_c_generator(cg, AM, "row")
+    gg.RSH.transformation_c_generator(cg, AM, "row", "gaussian")
 
 
 def test_library_gen():
-    gg.c_gen.generate_c_gau2grid(4, path="/tmp")
+
+    temp_dir = tempfile.mkdtemp()
+    gg.c_gen.generate_c_gau2grid(4, path=temp_dir)
+    shutil.rmtree(temp_dir)
 
 
 def test_pybind11_gen():
